@@ -3,8 +3,9 @@ use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct Image {
-    pub title: String,
     pub url: String,
+    pub title: Option<String>,
+    pub dimensions: Option<ImageDimensions>,
 }
 
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
